#
# spec file for package python-healpy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%bcond_without test
%define psuffix -test
%else
%bcond_with test
%define psuffix %{nil}
%endif
%{?sle15_python_module_pythons}
Name:           python-healpy%{?psuffix}
Version:        1.18.1
Release:        1.1
Summary:        Python library to handle pixelated data on the sphere based on HEALPix
License:        GPL-2.0-only
URL:            https://github.com/healpy/healpy
Source:         https://files.pythonhosted.org/packages/source/h/healpy/healpy-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.10}
BuildRequires:  %{python_module numpy-devel >= 1.19}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm >= 8}
BuildRequires:  %{python_module setuptools >= 60}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(healpix_cxx) >= 3.83
BuildRequires:  pkgconfig(libsharp)
Requires:       python-astropy >= 4.0
Requires:       python-numpy >= 1.19
Recommends:     python-matplotlib
Recommends:     python-scipy
Requires(post): update-alternatives
Requires(postun):update-alternatives
%if %{with test}
# SECTION Additional test requirements
# Symbol clashes with astropy < 4.0
BuildRequires:  %{python_module astropy >= 4.0}
BuildRequires:  %{python_module healpy = %{version}}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module scipy}
# /SECTION
%endif
%python_subpackages

%description
healpy is a Python package to handle pixelated data on the sphere. It is based
on the Hierarchical Equal Area isoLatitude Pixelization (HEALPix) scheme and
bundles the HEALPix C++ library.

healpy provides utilities to:
* convert between sky coordinates and pixel indices in HEALPix nested and ring schemes
* find pixels within a disk, a polygon or a strip in the sky
* apply coordinate transformations between Galactic, Ecliptic and Equatorial reference frames
* apply custom rotations either to vectors or full maps
* read and write HEALPix maps to disk in FITS format
* upgrade and downgrade the resolution of existing HEALPix maps
* visualize maps in Mollweide, Gnomonic and Cartographic projections
* transform maps to Spherical Harmonics space and back using multi-threaded C++ routines
* compute Auto and Cross Power Spectra from maps and create map realizations from spectra

%prep
%autosetup -p1 -n healpy-%{version}
chmod -x lib/healpy/data/planck_*cmap.dat

%build
%if %{without test}
export CFLAGS="%{optflags}"
%pyproject_wheel
%endif

%install
%if %{without test}
%pyproject_install
%python_clone -a  %{buildroot}%{_bindir}/healpy_get_wmap_maps.sh
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%post
%python_install_alternative healpy_get_wmap_maps.sh

%postun
%python_uninstall_alternative healpy_get_wmap_maps.sh

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license COPYING
%python_alternative %{_bindir}/healpy_get_wmap_maps.sh
%{python_sitearch}/healpy/
%{python_sitearch}/healpy-%{version}*-info/

%else

%check
export PYTEST_DEBUG_TEMPROOT=$(mktemp -d -p ./)
export MPLCONFIGDIR=${PWD}
# Skip tests requiring network access
%pytest_arch -k 'not (test_astropy_download_file or test_rotate_map_polarization or test_pixelweights_local_datapath)' ./test/

%endif

%changelog
* Sun Jun 15 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.18.1:
  * Updated CFITSIO to 4.6.2 (gh#heaply/heaply#1000).
  * Fix for map2alm_lsq shape error with Scipy 1.15
    (gh#heaply/heaply#991).
  * Fix overflow for map2alm_lsq with Nside 8192
    (gh#heaply/heaply#976).
  * Improvements to projview (gh#heaply/heaply#984).
- Split off tests into a separate multibuild flavour.
* Wed Feb 12 2025 Ben Greiner <code@bnavigator.de>
- Update to 1.18.0
  * Update C++ sources to 3.83 #973
  * Drop support for Python 3.9 #967
  * Added lonlat parameter to newprojplot #963
  * Fix query_disc missing pixels near poles, fixed in C++ #968
  * Warn users about ud_grade effect on spectra in docstring #960
  * Update CFITSIO to 4.5.0 and ensure we build it as shared lib
    [#942]
- Release 1.17.3
  * Rename trapz function to support latest scipy version #953
- Release 1.17.1
  * Just fixing an issue in the PyPI publish action
- Release 1.17.0
  * The most important modification is that now scipy and
    matplotlib are optional dependencies, install them with pip
    install healpy[all]. Also includes a lot of packaging fixes.
  * Optional dependencies by @swyatt7 in #910
  * Fix errors with Matplotlib 3.9 by @QuLogic in #944
  * [doc] pull docstrings from dist2holes and hotspots cython
    functions by @zonca in #920
  * Improve docs of read_alm by @zonca in #930
  * update C++ sources to SVN commit 1238 by @zonca in #917
  * update healpix sources to r1239 by @zonca in #941
  * Use alice3 from libhealpix_cxx by @lpsinger in #939
  * Fix pytest-cython errors by requiring pytest<8 by @lpsinger in
    [#913]
- Drop patches
  * python-healpy-matplotlib-1_9-compat.patch
  * python-healpy-scipy-1_14-compat.patch
- Remove devel package: Unused, the src is no longer in the
  system site
* Sat Jul 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add python-healpy-scipy-1_14-compat.patch: Account for the
  renaming of trapz to trapezoid in scipy 1.14.
- Add python-healpy-matplotlib-1_9-compat.patch: Fix compatibility
  with matplotlib >= 3.9; upstream commit 0b1f498 rebased for
  current version.
* Wed Oct  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.16.6:
  * Support for Python 3.12.
- Split out -devel package containing C++ headers/sources.
* Mon Sep  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.16.5:
  * No documented changes.
- Changes from vesion 1.16.4:
  * Updated HEALPix C++ to fix compilation issue, no actual
    changes to the library (gh#healpy/healpy#875).
  * Fix support for latest Cython (gh#healpy/healpy#862).
  * Minor changes to packaging and actions (gh#healpy/healpy#872,
    gh#healpy/healpy#865, gh#healpy/healpy#864,
    gh#healpy/healpy#863).
- Changes from version 1.16.3:
  * Drop support for Python 3.7 (gh#healpy/healpy#821).
  * Added wheels for aarch64 under emulation in Github Actions
    (gh#healpy/healpy#819).
  * Allow pixelfunc.get_interp_val to operate on multiple maps
    (gh#healpy/healpy#816).
  * Add healpy-specific HealpyDeprecationWarning instead of using
    astropy's (gh#healpy/healpy#822).
  * Bugfix in Rotator in rmul (gh#healpy/healpy#810).
- Use wheel macros to package; new BuildRequires:
  python-setuptools_scm, python-pip, python-wheel.
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 1.16.2:
  * Add `resize_alm` function to change a Alm array to a
    different ell max
  * Build wheels for Python 3.11
  * Instructions on how to build an optimized package for healpy
* Tue Oct 11 2022 pgajdos@suse.com
- version update to 1.16.1
  * Updated CFITSIO included in `healpy` to 4.1.0, necessary for
    compatibility with Apple ARM chips
- Changes from versions 1.16.0:
  * Update HEALPix C++ sources to revision 1206
  * Do not normalize binary arrays
  * Fix unncessary log warning message in plots
  * Fixed double application of `margins` in visualization
    functions when using subplot syntax and implemented
    `margins` parameter for `mollview`, `orthview`, and
    `azeqview` when subplot syntax is not used
  * Fixed `reuse_axes=True` for `cartview` and `gnomview`
  * New features in `projview`: subplots, remove monopole-dipole,
    labels, tickmarks, graticule, Planck and WMAP colormaps
  * Fixed the CFITSIO version mismatch warning
  * Added colorbar ticks and normalization
- python-six is not required
* Tue Jul 12 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.15.2:
  * Update HEALPix C++ sources after update of ABI
    (gh#healpy/healpy#746).
- Changes from versions 1.15.1:
  * New function hp.blm_gauss to generate alm of a gaussian beam
    (gh#healpy/healpy#735).
  * Implement rotation in the graticule of projview
    (gh#healpy/healpy#732).
  * Explain how to create a local datapath for pixel weights
    (gh#healpy/healpy#720).
  * Improvement on is_seq to avoid synalm breaking on JAX input
    arrays, added unit tests (gh#healpy/healpy#716).
  * Upgraded HEALPix C++ sources to HEALPix 3.8.1, fixing
    incompatibility with CFITSIO 4 (gh#healpy/healpy#727) and
    (gh#healpy/healpy#743).
* Wed Aug 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.15.0:
  * Write_map keeps dtype of input map array instead of float32
    (gh#healpy/healpy#688).
  * Read_map keeps dtype of FITS file instead of upcasting to
    float64 (gh#healpy/healpy#688).
  * Write_cl uses dtype of input cl instead of float64
    (gh#healpy/healpy#688).
  * Changed all warnings to using the logging module, deprecated
    all verbose keywords (gh#healpy/healpy#693).
  * Experimental projview function to plot maps using projections
    from matplotlib (gh#healpy/healpy#695).
  * Flip sign for spin-0 alm2map_spin and map2alm_spin
    (gh#healpy/healpy#707).
  * Support transparency in plotting with the alpha parameter
    (gh#healpy/healpy#696).
  * Removed the note that we will change order of cl in synfast
    and synalm, we will leave new=False default
    (gh#healpy/healpy#687).
  * Added convenice functions order2npix and npix2order
    (gh#healpy/healpy#685).
  * Support nested maps hp.smoothing (gh#healpy/healpy#678).
  * Improvements of the build system (gh#healpy/healpy#660).
  * Automatically build wheels for Linux/MacOS on Github actions
    (gh#healpy/healpy#656).
  * Drop support for Python 2.7-3.5 (gh#healpy/healpy#658).
  * Allow OBJECT FITS header not to be a string
    (gh#healpy/healpy#665).
  * Fixed indexing issue in bl2beam (gh#healpy/healpy#667).
  * Fixed map2alm_spin bug for masked input
    (gh#healpy/healpy#651).
  * Minor bugfixes:
  - Accept None for cls in synalm (gh#healpy/healpy#711)
  - Get nside from length of array in read_map
    (gh#healpy/healpy#710).
  - Fix spin 0 transforms in alm2map_spin
    (gh#healpy/healpy#708).
  - Raise exception for rotate_alm with complex64 inputs
    (gh#healpy/healpy#704).
  - Replace deprecated numpy aliases (gh#healpy/healpy#698).
- New BuildRequires: python-Cython.
- Drop python-healpy-drop-pytest-runner.patch: Upstream no longer
  requires pytest-runner for its tests.
* Thu Jan 21 2021 Benjamin Greiner <code@bnavigator.de>
- Skip python36 because astropy is python >= 3.7
* Sun Aug 16 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add python-healpy-drop-pytest-runner.patch: Drop pytest-runner
  which is unnecessary when running tests via pytest directly
  (gh#healpy/healpy#649).
* Sun Aug 16 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package
